@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2015 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -112,6 +112,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
+import com.openexchange.ajax.LoginServlet;
 import com.openexchange.ajax.fields.LoginFields;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.exception.OXException;
@@ -136,6 +137,7 @@ import com.openexchange.saml.state.DefaultLogoutRequestInfo;
 import com.openexchange.saml.state.LogoutRequestInfo;
 import com.openexchange.saml.state.StateManagement;
 import com.openexchange.saml.tools.CryptoHelper;
+import com.openexchange.saml.tools.SAMLLoginTools;
 import com.openexchange.saml.validation.AuthnResponseValidationResult;
 import com.openexchange.saml.validation.ValidationException;
 import com.openexchange.saml.validation.ValidationStrategy;
@@ -255,7 +257,7 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
             }
 
             Assertion bearerAssertion = validationResult.getBearerAssertion();
-            AuthenticationInfo authInfo = backend.resolveAuthnResponse(response, bearerAssertion);
+            AuthenticationInfo authInfo = backend.resolveAuthnResponse(response, bearerAssertion, requestInfo);
             LOG.debug("User {} in context {} is considered authenticated", authInfo.getUserId(), authInfo.getContextId());
 
             enhanceAuthInfo(authInfo, bearerAssertion);
@@ -271,12 +273,12 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
                 .setScheme(getRedirectScheme(httpRequest))
                 .setHost(requestInfo.getDomainName())
                 .setPath(getRedirectPathPrefix() + "login")
-                .setParameter("action", "redeemReservation")
-                .setParameter("token", sessionToken);
+                .setParameter(LoginServlet.PARAMETER_ACTION, SAMLLoginTools.ACTION_SAML_LOGIN)
+                .setParameter(SAMLLoginTools.PARAM_TOKEN, sessionToken);
 
             String loginPath = requestInfo.getLoginPath();
             if (loginPath != null) {
-                redirectLocation.setParameter(LoginFields.UI_WEB_PATH_PARAM, loginPath);
+                redirectLocation.setParameter(SAMLLoginTools.PARAM_LOGIN_PATH, loginPath);
             }
 
             String clientID = requestInfo.getClientID();
@@ -337,8 +339,8 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
                 .setScheme(getRedirectScheme(httpRequest))
                 .setHost(requestInfo.getDomainName())
                 .setPath(getRedirectPathPrefix() + "login")
-                .setParameter("action", "samlLogout")
-                .setParameter("session", requestInfo.getSessionId())
+                .setParameter(LoginServlet.PARAMETER_ACTION, SAMLLoginTools.ACTION_SAML_LOGOUT)
+                .setParameter(LoginServlet.PARAMETER_SESSION, requestInfo.getSessionId())
                 .build();
 
             Tools.disableCaching(httpResponse);
@@ -476,6 +478,10 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
         }
     }
 
+    private String getDomainName(HttpServletRequest httpRequest) {
+        return SAMLLoginTools.getHostName(services.getOptionalService(HostnameService.class), httpRequest);
+    }
+
     private String compileLogoutRequestRedirectURI(String logoutRequestXML, String relayState) throws OXException {
         String encoded = deflateAndEncode(logoutRequestXML);
         try {
@@ -768,20 +774,6 @@ public class WebSSOProviderImpl implements SAMLWebSSOProvider {
         }
     }
 
-    private String getDomainName(HttpServletRequest httpRequest) {
-        HostnameService hostnameService = services.getOptionalService(HostnameService.class);
-        if (hostnameService == null) {
-            return httpRequest.getServerName();
-        }
-
-        String hostname = hostnameService.getHostname(-1, -1);
-        if (hostname == null) {
-            return httpRequest.getServerName();
-        }
-
-        return hostname;
-    }
-
     private AuthnRequest customizeAuthnRequest(AuthnRequest authnRequest, HttpServletRequest httpRequest, HttpServletResponse httpResponse) throws OXException {
         WebSSOCustomizer customizer = backend.getWebSSOCustomizer();
         if (customizer != null) {
